pub fn spawn<F>(future: F) -> JoinHandle<F::Output> ⓘExpand description
Spawns a future onto the current thread’s runtime
This is a convenience function that uses a thread-local runtime. For DLL boundary safety, create and use an explicit Runtime instead.
This function is only available when the std feature is enabled.